#
# spec file for package gtypist
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gtypist
Version:        2.9.5
Release:        4.1
Summary:        Universal typing tutor
License:        GPL-3.0-only
Group:          Amusements/Teaching/Other
URL:            http://gnu.org/software/gtypist/
Source:         http://ftp.gnu.org/gnu/gtypist/%name-%version.tar.xz
Source2:        http://ftp.gnu.org/gnu/gtypist/%name-%version.tar.xz.sig
Source3:        %name.keyring
Patch1:         gcc14.patch
BuildRequires:  bison
BuildRequires:  ncurses-devel
BuildRequires:  xz
PreReq:         %install_info_prereq

%description
GNU Typist (typist) is a universal typing tutor. You can learn
correct typing and improve your skills by practising its exercises on
a regular basis. Its main features are:

* It comes with several typing tutorials: in Czech, English (Qwerty,
  Dvorak and Colemak keyboards), Russian and Spanish, as well as
  simpler exercises in German, French and Norwegian.

* It interprets a simple and intuitive scripting language that
  describes typing tutorials. You can easily modify existing
  tutorials or create new ones according to your needs.

* Users can navigate through lessons through an easy to use arrow key
  based menu interface. 'vi' up, down, left and right keys can be
  used too.

%package lang
Summary:        Language files for package gtypist
Group:          System/Localization
Requires:       gtypist = %{version}

%description lang
GNU Typist (typist) is a universal typing tutor. You can learn
correct typing and improve your skills by practising its exercises on
a regular basis.

This subpackage contain the translations for the package gtypist.

%prep
%autosetup -p1

%build 
%configure
%make_build

%install
%make_install
%find_lang %name

%post
for i in "%_infodir"/gtypist*.gz; do
	%install_info --info-dir="%_infodir" "$i"
done;

%preun
for i in "%_infodir"/gtypist*.gz; do
	%install_info_delete --info-dir="%_infodir" "$i"
done;

%files
%_bindir/gtypist
%_bindir/typefortune
%_datadir/gtypist/
%_infodir/gtypist*.gz
%_datadir/man/man1/gtypist.1*
%_datadir/man/man1/typefortune.1*

%files lang -f %name.lang

%changelog
* Sat Nov  2 2024 Jan Engelhardt <jengelh@inai.de>
- Replace escdelay.diff by new gcc14.patch to resolve more FTBFS
* Tue Aug 25 2020 Jan Engelhardt <jengelh@inai.de>
- Remove old rpm recipe constructs.
* Wed Sep 23 2015 jengelh@inai.de
- Add escdelay.diff to work around unintended use of ncurses API
* Wed Oct  1 2014 jengelh@inai.de
- Update to new upstream release 2.9.5
  * improved CPM/WPM calculation precision
  * Q series
  * fix for Colemak lesson (updated top 1000 most frequently used
  words)
* Tue Sep 23 2014 jengelh@inai.de
- Drop gpg-offline build-time requirement; this is now handled by
  the local source validator
* Tue Feb  4 2014 jengelh@inai.de
- Update to new upstream release 2.9.4
  * This release has a fix for Colemak lesson. There are minor
  documentation fixes.
* Sat Jun  8 2013 jengelh@inai.de
- Update to new upstream release 2.9.3
  * This release fixes Alt+some key being treated as ESCAPE and
  clearing drills, updates the ktouch lesson import script, updates
  lessons imported from ktouch (fixing an issue with lines over 80
  characters causing errors, amongst other things), and fixes
  errors in lessons.
* Mon Dec 17 2012 jengelh@inai.de
- Initial package (version 2.9.2) for build.opensuse.org
